@@ -477,7 +477,7 @@ int _msg_box(char *msg, char *title, int buttons)
       case(RIGHT_KEY):
       case(LEFT_KEY):
       case(TAB_KEY):
-	  bx = x + (msgH-3);
+	  bx = x + (msgH-2);
 	  by = y + ((msgW-16)/2) - 2;
 	  by += 12;
 	  if(sel == 0 && buttons == 26) 
@@ -586,9 +586,13 @@ void drawBox(int x1, int y1, int x2, int y2, char *title, int clearArea)
   //Draw the box first//
   setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   fprintf(stdout, "\x1b[%d;%dH", x1, y1);//control sequence to move cursor
-  fprintf(stdout, "\e%@\e(0");	//enter the Alternative Char Set (ACS) Mode 
-				//to draw boxes, as standard ISO charset 
-				//will not allow us to draw boxes
+  /* NOTE: this is a TERRIBLE hack! but it does the following:
+   *       "\e)0" will define G1 charset to be "VT100 Graphics Mapping"
+   *       "\x0e" a.k.a. ^N, activates G1 charset.
+   */
+  fprintf(stdout, "\e)0\x0e");
+  fflush(stdout);
+
   putchar(ULC);			//print the upper-left corner
   for(i = 0; i < (y2-y1)-1; i++)
   {
@@ -610,9 +614,16 @@ void drawBox(int x1, int y1, int x2, int y2, char *title, int clearArea)
     putchar(HB);			//print the horizontal lower bar
   }
   putchar(LRC);  
-  fprintf(stdout, "\e(B");		//exit Alternative Char Set (ACS) Mode
+  //fprintf(stdout, "\e(B");		//exit Alternative Char Set (ACS) Mode
+  //fprintf(stdout, "\e[0m\e(B\e)0\017\e[?5l\e7\e[r\e8");
+
+  /* NOTE: this is a TERRIBLE hack! but it does the following:
+   *       "\x0f" a.k.a. ^O, activates G0 charset.
+   */
+  fprintf(stdout, "\x0f");
+  fflush(stdout);  
+  //printf("\x1b[0m");
   
-  printf("\x1b[0m");
   //Then put on the box title, if any//
   if(title != NULL) 
   {
