@@ -23,19 +23,30 @@
 
 #include <string.h>
 
-typedef char *str;// = (char *)malloc(1);
+/* define the String type */
+typedef char *str;
 
+/* Get the index of a char in a string */
 int indexof(str string, char chr);
+/* Get the next index of a char in a string */
 int nindexof(char chr);
+/* Get the last index of a char in a string */
 int lindexof(str string, char chr);
 
+/* Get the substring starting at .. */
 str substr(str string, int start);
+/* Get the substring starting at .. with a length of .. */
 str nsubstr(str string, int start, int length);
+/* Trim the lefthand whitespace chars */
 str ltrim(str string);
+/* Trim the righthand whitespace chars */
 str rtrim(str string);
+/* Trim the whitespace chars from both sides */
 str trim(str string);
 
-str toupper(str string);
-str tolower(str string);
+/* Convert string to uppercase letters */
+str uppercase(str string);
+/* Convert string to lowercase letters */
+str lowercase(str string);
 
-#endif
\ No newline at end of file
+#endif /* __STRINGS_H */
\ No newline at end of file
