@@ -106,7 +106,12 @@ int main(int argc, char *argv[])
  //very important to restore keyboard state to its
  //previous state before exiting
  //restore_kbd();
+ setScreenColors(WHITE, BGBLACK);
  restoreTerminal();
+ setScreenColors(WHITE, BGBLACK);
+ clearScreen();
+ fprintf(stdout, "\x1b[24m");
+ fflush(stdout);
  exit(0);
 }//end main
 
@@ -129,7 +134,7 @@ void drawStatusBar()
   //reposition the cursor
   if(activeWindow == TOOLBOX_WIN) 
   {
-    printf("\e[%d;%dH", selected_tool+4, SCREEN_W-14+strlen(tool[selected_tool]));
+    printf("\e[%d;%dH", selected_tool+4, (int)(SCREEN_W-14+strlen(tool[selected_tool])));
   } 
   else 
   {
