@@ -1,30 +1,34 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014 (c)
+ *    Copyright 2014, 2015 (c)
  * 
  *    file: defs.h
- *    This file is part of mino (Mino).
+ *    This file is part of mino.
  *
- *    mino (Mino) is free software: you can redistribute it and/or modify
+ *    mino is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
  *    the Free Software Foundation, either version 3 of the License, or
  *    (at your option) any later version.
  *
- *    mino (Mino) is distributed in the hope that it will be useful,
+ *    mino is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *    GNU General Public License for more details.
  *
  *    You should have received a copy of the GNU General Public License
- *    along with mino (Mino).  If not, see <http://www.gnu.org/licenses/>.
+ *    along with mino.  If not, see <http://www.gnu.org/licenses/>.
  */    
 
 #include <stdio.h>
+#include <errno.h>
 
 #ifndef __Mino_PRO_H
 #define __Mino_PRO_H
 
+#ifndef __BOOL_DEFINED_
+#define __BOOL_DEFINED_
 typedef int bool;
+#endif
 
 int SCREEN_W;
 int SCREEN_H;
@@ -217,5 +221,9 @@ void putuchar(int pos, int index);
 void putunichar(char *ch);
 int GNU_DOS_LEVEL;
 int makestr(char *newstr, char *str);
+void move_lines_up(int first, int last);
+void move_lines_down(int first, int last);
+void calcCharCarry(int pos);
+bool is_whitespace(char c);
 
 #endif
