@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015 (c)
+ *    Copyright 2014, 2015, 2016 (c)
  * 
  *    file: main.c
  *    This file is part of mino.
@@ -35,6 +35,9 @@
 #include <sys/ioctl.h>
 #include <stdlib.h>
 
+extern int fcloseall (void);    /* stdio.h */
+extern char * strcasestr (const char *HAYSTACK, const char *NEEDLE);    /* string.h */
+
 #define EXIT()		\
 {			\
  restoreTerminal();	\
@@ -2381,9 +2384,13 @@ void drawBox(int x1, int y1, int x2, int y2, char *title, int clearArea)
   //Draw the box first//
   setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   fprintf(stdout, "\x1b[%d;%dH", x1, y1);	//control sequence to move cursor
-  fprintf(stdout, "\e%@\e(0");		//enter the Alternative Char Set (ACS) Mode 
-					//to be able to draw boxes, as standard ISO charset 
-					//will not allow us to draw boxes
+  /* NOTE: this is a TERRIBLE hack! but it does the following:
+   *       "\e)0" will define G1 charset to be "VT100 Graphics Mapping"
+   *       "\x0e" a.k.a. ^N, activates G1 charset.
+   */
+  fprintf(stdout, "\e)0\x0e");
+  fflush(stdout);
+
   putchar(ULC);					//print the upper-left corner
   for(i = 0; i < (y2-y1)-1; i++) 
   {
@@ -2413,7 +2420,11 @@ void drawBox(int x1, int y1, int x2, int y2, char *title, int clearArea)
     putchar(HB);			//print the horizontal lower bar
   }
   putchar(LRC);  
-  fprintf(stdout, "\e(B");		//exit the Alternative Char Set (ACS) Mode
+  /* NOTE: this is a TERRIBLE hack! but it does the following:
+   *       "\x0f" a.k.a. ^O, activates G0 charset.
+   */
+  fprintf(stdout, "\x0f");
+  fflush(stdout);  
   
   //Then put on the box title, if any//
   if(title != NULL) 
@@ -2492,4 +2503,4 @@ void calcCharCarry(int pos)
       j = 0 ? TAB_CHARS : j;
       selectedCharCarry+=(j-1);
     }
-}
\ No newline at end of file
+}
