@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014 (c)
+ *    Copyright 2014, 2015 (c)
  * 
  *    file: msgbox.c
  *    This file is part of mino (Mino).
@@ -26,9 +26,12 @@
 #include "kbd.h"
 #include "options.h"
 
- int inputLen = 0;	//how long is the input?
- int highlightChar = 0;	//which char is under the cursor?
- int firstVisChar = 0;	//which char is the first in input line? (used when scrolling a long input)
+/* how long is the input? */
+int inputLen = 0;
+/* which char is under the cursor? */
+int highlightChar = 0;
+/* which char is the first in input line? (used when scrolling a long input) */
+int firstVisChar = 0;
 
 void putunichar(char *ch)
 {
@@ -54,7 +57,6 @@ char* inputBox(char *msg, char *title)
   int msgW = 0;
   int msgH = 0;
   int j, i = 0;
-  //char *k[10];
 
   setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   j = 0;
@@ -101,32 +103,26 @@ char* inputBox(char *msg, char *title)
     }
   }
 
- //put an empty field for user entry
+ /* put an empty field for user entry */
  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
- //setScreenColors(BLUE, BGWHITE);
  fprintf(stdout, "\e[%d;%dH", x+(msgH-4), y);
  for(i = 0; i < msgW-3; i++) putchar(' ');
  
- //then draw button(s)//
+ /* then draw button(s) */
  int bx, by;
  int sel = 2;	//selection: 0=OK, 1=CANCEL, 2=INPUT FIELD
- //int inputLen = 0;	//how long is the input?
- //int highlightChar = 0;	//which char is under the cursor?
- //int firstVisChar = 0;	//which char is the first in input line? (used when scrolling a long input)
- 
- //for(i = 0; i <= MAX_INPUT_MSG_LEN; i++) input[i] = '\0';	//init string to NULLs
+
  memset(input, '\0', MAX_INPUT_MSG_LEN*4);
  
-    bx = x + (msgH-2);
-    by = y + ((msgW-16)/2) - 2;
-    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
-    //setScreenColors(WHITE, BGRED);
-    fprintf(stdout, "\x1b[%d;%dH", bx, by);
-    fprintf(stdout, "   OK   ");
-    by += 12;
-    fprintf(stdout, "\x1b[%d;%dH", bx, by);
-    fprintf(stdout, " CANCEL ");
-    fprintf(stdout, "\x1b[%d;%dH", bx-2, y);	//adjust cursor to point at input field
+ bx = x + (msgH-2);
+ by = y + ((msgW-16)/2) - 2;
+ setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
+ fprintf(stdout, "\x1b[%d;%dH", bx, by);
+ fprintf(stdout, "   OK   ");
+ by += 12;
+ fprintf(stdout, "\x1b[%d;%dH", bx, by);
+ fprintf(stdout, " CANCEL ");
+ fprintf(stdout, "\x1b[%d;%dH", bx-2, y);	//adjust cursor to point at input field
   
  fflush(stdout);
  //wait for user response//
@@ -266,6 +262,7 @@ do_del:
 	  input[i*4+3] = input[i*4+7];
 	}
 	input[(--inputLen)*4] = '\0';
+	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	fprintf(stdout, "\x1b[%d;%dH", bx-2, y+highlightChar);	//adjust cursor to point at input field
 	for(i = highlightChar; i < (msgW-3); i++) 
 	{
@@ -303,6 +300,7 @@ do_del:
 	  }
 	  input[(--inputLen)*4] = '\0';
 	}//end else
+	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	fprintf(stdout, "\x1b[%d;%dH", bx-2, y);	//adjust cursor to point at input field
 	for(i = firstVisChar; i < (firstVisChar+msgW-3); i++) 
 	{
@@ -317,7 +315,6 @@ do_del:
 enterInputChar:
 	    if(strlen(input)/4 >= MAX_INPUT_MSG_LEN) break;
 	    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
-	    //setScreenColors(BLUE, BGWHITE);
 	    //inserting in the middle of a string means we need to shift all chars one position
 	    //to the right before inserting the new char at the highlighted position.
 	    if(input[highlightChar*4] != '\0') 
@@ -347,19 +344,19 @@ enterInputChar:
 	    {	//need to scroll string
 	      fprintf(stdout, "\x1b[%d;%dH", bx-2, y);	//adjust cursor to point at input field
 	      highlightChar--;
-	      for(i = ++firstVisChar; i <= (firstVisChar+msgW-3); i++) 
+	      for(i = ++firstVisChar; i <= (firstVisChar+msgW-4); i++) 
 		putunichar(input+(i*4));
 	      fprintf(stdout, "\x1b[%d;%dH", bx-2, y+msgW-4);	//adjust cursor to point at input field
 	    } 
 	    else 
 	    {				//no need to scroll string, just output the char
-	      putunichar(input+((--highlightChar)*4)); 
-	      highlightChar++;
-	      fprintf(stdout, "\x1b[%d;%dH", bx-2, y+highlightChar+1);	//adjust cursor to point at input field
+	      putunichar(input+((highlightChar-1)*4)); 
+	      //highlightChar++;
+	      fprintf(stdout, "\x1b[%d;%dH", bx-2, y+highlightChar);	//adjust cursor to point at input field
 	      if(inputLen > firstVisChar+highlightChar) 
 	      {	//there are some chars to the right side
 		//for(i = firstVisChar+highlightChar; i < inputLen; i++) putchar(input[i]);
-		for(i = highlightChar; i < (msgW-3); i++) 
+		for(i = highlightChar; i < (msgW-4); i++) 
 		{
 		  if(input[(firstVisChar+i)*4] == '\0') putchar(' ');
 		  else putunichar(input+((firstVisChar+i)*4));
