@@ -362,6 +362,7 @@ void optionsMenu_Tab_Spaces()
   if(t) 
   {
     char *t2 = (char *) malloc(10);
+    if(!t2) { msgBox("Insufficient memory", OK, ERROR); return; }
     makestr(t2, t);
     if(atoi(t2) <= 0) return;
     TAB_CHARS = atoi(t2);
@@ -384,6 +385,7 @@ void optionsMenu_Reset_Config()
 	return;
       }
       config_file_name = (char *) malloc(strlen(pass->pw_dir)+11);
+      if(!config_file_name) { msgBox("Insufficient memory", OK, ERROR); refreshView(); return; }
       strcpy(config_file_name, pass->pw_dir);
       strcat(config_file_name, "/");
       strcat(config_file_name, ".mino.conf");
@@ -444,6 +446,7 @@ void write_config_file()
 	return;
       }
       config_file_name = (char *) malloc(strlen(pass->pw_dir)+11);
+      if(!config_file_name) { msgBox("Insufficient memory", OK, ERROR); refreshView(); return; }
       strcpy(config_file_name, pass->pw_dir);
       strcat(config_file_name, "/");
       strcat(config_file_name, ".mino.conf");
