@@ -33,26 +33,12 @@ void getScreenSize()
 {
  struct winsize w;
  ioctl(0, TIOCGWINSZ, &w);	//find the size of the view
- //printf("Rows: %d\n", w.ws_row);
- //printf("Cols: %d\n", w.ws_col);
  SCREEN_H = w.ws_row;
  SCREEN_W = w.ws_col;
 }
 
 void clearScreen() 
 {
- /*char *cls = "\x1b[2J";	//console control sequence: ESC[2J (ESC = 27 Dec = Hex "1b")
- int clsLen = strlen(cls);
- //call it volatile to force the compiler to put asm code in this place, no optimizations
- __asm__ __volatile__ (
-   "movl $4, %%eax\n\
-   movl $1, %%ebx\n\
-   int $0x80"
-   ://output registers goes here -- if any
-   :"d"(clsLen),"c"(cls)	//input vars (in braces) put into registers "in quotes"
-   ://registers whose contents are not valid any more goes here -- if any
- );
- */
  fprintf(stdout, "\x1b[2J");
  fprintf(stdout, "\x1b[37;4m");
  fprintf(stdout, "\e[3J\e[1;1H");
